@@ -28,18 +28,6 @@
 namespace nux
 {
 DECLARE_LOGGER(logger, "nux.core.object");
-namespace
-{
-bool debug_object_allocation_stack()
-{
-  // If the extra long environment variable is set, then every object that is
-  // created will record it's backtrace during allocation.  This will slow
-  // down the library, so only use for local debugging.
-  static bool extra_debugging(::getenv("NUX_DEBUG_OBJECT_ALLOCATION_STACK"));
-  return extra_debugging;
-}
-
-}
 
   NUX_IMPLEMENT_ROOT_OBJECT_TYPE (Trackable);
   NUX_IMPLEMENT_OBJECT_TYPE (Object);
@@ -74,10 +62,6 @@ bool debug_object_allocation_stack()
       sout << "\t" << ++index << " Undeleted object: Type "
            << obj->GetTypeName() << ", "
            << obj->GetAllocationLocation() << "\n";
-      if (debug_object_allocation_stack())
-      {
-        sout << obj->allocation_stacktrace_ << "\n\n";
-      }
 
       OutputDebugString(sout.str().c_str());
 
@@ -90,10 +74,6 @@ bool debug_object_allocation_stack()
       std::cerr << "\t" << ++index << " Undeleted object: Type "
                 << obj->GetTypeName() << ", "
                 << obj->GetAllocationLocation() << "\n";
-      if (debug_object_allocation_stack())
-      {
-        std::cerr << obj->allocation_stacktrace_ << "\n\n";
-      }
     }
 #endif
 #endif
@@ -261,11 +241,6 @@ bool debug_object_allocation_stack()
     sout << ":" << __Nux_LineNumber__;
     allocation_location_ = sout.str();
 
- #if defined(NUX_OS_LINUX)
-    if (debug_object_allocation_stack()) {
-      allocation_stacktrace_ = logging::Backtrace();
-    }
- #endif
 #else
     __Nux_FileName__ = __Nux_FileName__;
     __Nux_LineNumber__ = __Nux_LineNumber__;
