@@ -23,7 +23,9 @@ void nux::GestureEvent::Reject()
 int main(int argc, char **argv)
 {
   ::testing::InitGoogleTest(&argc, argv);
+#if G_ENCODE_VERSION (GLIB_MAJOR_VERSION, GLIB_MINOR_VERSION) <= GLIB_VERSION_2_34
   g_type_init();
+#endif
   nux::NuxInitialize(0);
 
   return RUN_ALL_TESTS();
